@@ -12,7 +12,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use constant DHTML_CLASS => 'data_treedumper_dhtml' ;
 
@@ -252,7 +252,7 @@ else
 </ul>
 
 <script type='text/javascript'>
-<![CDATA[
+<!--
 
 var a_id_array= new Array
 		(
@@ -401,7 +401,7 @@ else if (document.layers)
 	}
 } 
 
-]]>
+-->
 </script>
 EOS
 	}
